@@ -1,23 +1,31 @@
-#include <QFileDialog>
-#include <QDebug>
-#include <QXmlQuery>
-#include <QXmlResultItems>
-#include <QTemporaryFile>
-#include <helpers/htmlentities.h>
-#include <utils/misc.h>
-#include <entities/tag.h>
-#include <QCryptographicHash>
 #include "evernoteimportdialog.h"
-#include "ui_evernoteimportdialog.h"
-#include "filedialog.h"
+
+#include <entities/note.h>
+#include <entities/notesubfolder.h>
+#include <entities/tag.h>
+#include <utils/misc.h>
+
+#include <QCryptographicHash>
+#include <QDebug>
+#include <QFileDialog>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
 #include <QRegularExpressionMatchIterator>
-#include <QtCore/QSettings>
+#include <QSettings>
+#include <QTemporaryFile>
 
-EvernoteImportDialog::EvernoteImportDialog(QWidget *parent) :
-        MasterDialog(parent),
-    ui(new Ui::EvernoteImportDialog) {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    #include <QXmlQuery>
+    #include <QXmlResultItems>
+#endif
+
+#include <utility>
+
+#include "filedialog.h"
+#include "ui_evernoteimportdialog.h"
+
+EvernoteImportDialog::EvernoteImportDialog(QWidget *parent)
+    : MasterDialog(parent), ui(new Ui::EvernoteImportDialog) {
     ui->setupUi(this);
     setupMetaDataTreeWidgetItems();
     ui->progressBar->hide();
@@ -26,33 +34,40 @@ EvernoteImportDialog::EvernoteImportDialog(QWidget *parent) :
     _importCount = 0;
 
     QSettings settings;
-    ui->imageImportCheckBox->setChecked(settings.value(
-            "EvernoteImport/ImageImportCheckBoxChecked", true).toBool());
-    ui->attachmentImportCheckBox->setChecked(settings.value(
-            "EvernoteImport/AttachmentImportCheckBoxChecked", true).toBool());
+    ui->imageImportCheckBox->setChecked(
+        settings
+            .value(QStringLiteral("EvernoteImport/ImageImportCheckBoxChecked"),
+                   true)
+            .toBool());
+    ui->attachmentImportCheckBox->setChecked(
+        settings
+            .value(QStringLiteral(
+                       "EvernoteImport/AttachmentImportCheckBoxChecked"),
+                   true)
+            .toBool());
 }
 
 EvernoteImportDialog::~EvernoteImportDialog() {
     QSettings settings;
-    settings.setValue("EvernoteImport/ImageImportCheckBoxChecked",
-            ui->imageImportCheckBox->isChecked());
-    settings.setValue("EvernoteImport/AttachmentImportCheckBoxChecked",
-            ui->attachmentImportCheckBox->isChecked());
+    settings.setValue(
+        QStringLiteral("EvernoteImport/ImageImportCheckBoxChecked"),
+        ui->imageImportCheckBox->isChecked());
+    settings.setValue(
+        QStringLiteral("EvernoteImport/AttachmentImportCheckBoxChecked"),
+        ui->attachmentImportCheckBox->isChecked());
 
     storeMetaDataTreeWidgetItemsCheckedState();
 
     delete ui;
 }
 
-int EvernoteImportDialog::getImportCount() {
-    return _importCount;
-}
+int EvernoteImportDialog::getImportCount() { return _importCount; }
 
 /**
  * Imports the notes from a selected file
  */
 void EvernoteImportDialog::on_fileButton_clicked() {
-    FileDialog dialog("EvernoteImport");
+    FileDialog dialog(QStringLiteral("Evernote Import"));
     dialog.setFileMode(QFileDialog::AnyFile);
     dialog.setAcceptMode(QFileDialog::AcceptOpen);
     dialog.setNameFilter(tr("Enex files") + " (*.enex)");
@@ -68,15 +83,31 @@ void EvernoteImportDialog::on_fileButton_clicked() {
     }
 }
 
+/**
+ * Initializes the progress bar with the count of notes from the XML in data
+ *
+ * @param data
+ */
+void EvernoteImportDialog::initNoteCount(const QString &data) {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    int count = countNotes(data);
+
+    ui->progressBar->setMaximum(count);
+    ui->progressBar->show();
+#endif
+}
+
+/** Disabled Till we have an xmlpatterns alternative **/
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 /**
  * Counts the notes from the XML in data
  *
  * @param data
  */
-int EvernoteImportDialog::countNotes(QString data) {
+int EvernoteImportDialog::countNotes(const QString &data) {
     QXmlQuery query;
     query.setFocus(data);
-    query.setQuery("en-export/note");
+    query.setQuery(QStringLiteral("en-export/note"));
     int count = 0;
 
     QXmlResultItems result;
@@ -91,25 +122,14 @@ int EvernoteImportDialog::countNotes(QString data) {
     return count;
 }
 
-/**
- * Initializes the progress bar with the count of notes from the XML in data
- *
- * @param data
- */
-void EvernoteImportDialog::initNoteCount(QString data) {
-    int count = countNotes(data);
-
-    ui->progressBar->setMaximum(count);
-    ui->progressBar->show();
-}
-
 /**
  * Imports and embeds images from an Evernote note
  *
  * @param content
  */
-QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
-    query.setQuery("resource");
+QString EvernoteImportDialog::importImages(const Note &note, QString content,
+                                           QXmlQuery query) {
+    query.setQuery(QStringLiteral("resource"));
 
     QXmlResultItems result;
     QHash<QString, MediaFileData> mediaFileDataHash;
@@ -128,11 +148,12 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
 
         // parse the mime data of the object
         QString mime;
-        query.setQuery("mime/text()");
+        query.setQuery(QStringLiteral("mime/text()"));
         query.evaluateTo(&mime);
 
         QRegularExpression mimeExpression(
-                "(.+)?\\/(.+)?", QRegularExpression::CaseInsensitiveOption);
+            QStringLiteral("(.+)?\\/(.+)?"),
+            QRegularExpression::CaseInsensitiveOption);
         QRegularExpressionMatch mimeMatch = mimeExpression.match(mime);
 
         if (mimeMatch.hasMatch()) {
@@ -141,21 +162,20 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
         }
 
         // we only want to import images
-        if (objectType != "image") {
+        if (objectType != QStringLiteral("image")) {
             continue;
         }
 
         // check the recognition attribute for an object type
         QString recognition;
-        query.setQuery("recognition/text()");
+        query.setQuery(QStringLiteral("recognition/text()"));
         query.evaluateTo(&recognition);
 
-        recognition.replace("\\\"", "\"");
+        recognition.replace(QStringLiteral("\\\""), QStringLiteral("\""));
 
-        match = QRegularExpression(
-                "objID=\"(.+?)\"",
-                QRegularExpression::CaseInsensitiveOption)
-                .match(recognition);
+        match = QRegularExpression(QStringLiteral("objID=\"(.+?)\""),
+                                   QRegularExpression::CaseInsensitiveOption)
+                    .match(recognition);
 
         QString objectId;
 
@@ -166,14 +186,15 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
         }
 
         QString data;
-        query.setQuery("data/text()");
+        query.setQuery(QStringLiteral("data/text()"));
         query.evaluateTo(&data);
 
         // if there is no object id set we generate the hash ourselves
         if (objectId.isEmpty()) {
             objectId = QString(QCryptographicHash::hash(
-                    QByteArray::fromBase64(data.toLatin1()),
-                    QCryptographicHash::Md5).toHex());
+                                   QByteArray::fromBase64(data.toLatin1()),
+                                   QCryptographicHash::Md5)
+                                   .toHex());
         }
 
         // store data in the QHash
@@ -186,7 +207,7 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
     }
 
     // match image tags
-    QRegularExpression re("<en-media.+?type=\"image/.+?\".*?>",
+    QRegularExpression re(QStringLiteral("<en-media.+?type=\"image/.+?\".*?>"),
                           QRegularExpression::CaseInsensitiveOption);
     QRegularExpressionMatchIterator i = re.globalMatch(content);
     QStringList importedObjectIds;
@@ -197,8 +218,8 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
         QString imageTag = imageMatch.captured(0);
 
         // check for the hash
-        QRegularExpression re2("hash=\"(.+?)\"",
-                              QRegularExpression::CaseInsensitiveOption);
+        QRegularExpression re2(QStringLiteral("hash=\"(.+?)\""),
+                               QRegularExpression::CaseInsensitiveOption);
         QRegularExpressionMatch hashMatch = re2.match(imageTag);
 
         if (!hashMatch.hasMatch()) {
@@ -217,7 +238,7 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
         MediaFileData mediaFileData = mediaFileDataHash[objectId];
 
         // get the markdown code for the image file data entry
-        QString markdownCode = getMarkdownForMediaFileData(mediaFileData);
+        QString markdownCode = getMarkdownForMediaFileData(note, mediaFileData);
 
         if (!markdownCode.isEmpty()) {
             // replace image tag with markdown code
@@ -237,9 +258,9 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
         MediaFileData mediaFileData = hashIterator.value();
 
         // get the markdown code for the image file data entry
-        QString markdownCode = getMarkdownForMediaFileData(mediaFileData);
+        QString markdownCode = getMarkdownForMediaFileData(note, mediaFileData);
 
-        content += "\n" + markdownCode;
+        content += QStringLiteral("\n") + markdownCode;
     }
 
     return content;
@@ -250,9 +271,10 @@ QString EvernoteImportDialog::importImages(QString content, QXmlQuery query) {
  *
  * @param content
  */
-QString EvernoteImportDialog::importAttachments(QString content,
+QString EvernoteImportDialog::importAttachments(const Note &note,
+                                                QString content,
                                                 QXmlQuery query) {
-    query.setQuery("resource");
+    query.setQuery(QStringLiteral("resource"));
 
     QXmlResultItems result;
     QHash<QString, MediaFileData> mediaFileDataHash;
@@ -270,11 +292,12 @@ QString EvernoteImportDialog::importAttachments(QString content,
 
         // parse the mime data of the object
         QString mime;
-        query.setQuery("mime/text()");
+        query.setQuery(QStringLiteral("mime/text()"));
         query.evaluateTo(&mime);
 
         QRegularExpression mimeExpression(
-                "(.+)?\\/(.+)?", QRegularExpression::CaseInsensitiveOption);
+            QStringLiteral("(.+)?\\/(.+)?"),
+            QRegularExpression::CaseInsensitiveOption);
         QRegularExpressionMatch mimeMatch = mimeExpression.match(mime);
 
         if (mimeMatch.hasMatch()) {
@@ -282,21 +305,20 @@ QString EvernoteImportDialog::importAttachments(QString content,
         }
 
         // we don't want to import images
-        if (objectType == "image") {
+        if (objectType == QStringLiteral("image")) {
             continue;
         }
 
         // check the recognition attribute for an object type
         QString recognition;
-        query.setQuery("recognition/text()");
+        query.setQuery(QStringLiteral("recognition/text()"));
         query.evaluateTo(&recognition);
 
-        recognition.replace("\\\"", "\"");
+        recognition.replace(QStringLiteral("\\\""), QStringLiteral("\""));
 
-        match = QRegularExpression(
-                "objID=\"(.+?)\"",
-                QRegularExpression::CaseInsensitiveOption)
-                .match(recognition);
+        match = QRegularExpression(QStringLiteral("objID=\"(.+?)\""),
+                                   QRegularExpression::CaseInsensitiveOption)
+                    .match(recognition);
 
         QString objectId;
 
@@ -307,19 +329,20 @@ QString EvernoteImportDialog::importAttachments(QString content,
         }
 
         QString data;
-        query.setQuery("data/text()");
+        query.setQuery(QStringLiteral("data/text()"));
         query.evaluateTo(&data);
 
         // if there is no object id set we generate the hash ourselves
         if (objectId.isEmpty()) {
             objectId = QString(QCryptographicHash::hash(
-                    QByteArray::fromBase64(data.toLatin1()),
-                    QCryptographicHash::Md5).toHex());
+                                   QByteArray::fromBase64(data.toLatin1()),
+                                   QCryptographicHash::Md5)
+                                   .toHex());
         }
 
         // find the filename
         QString fileName;
-        query.setQuery("resource-attributes/file-name/text()");
+        query.setQuery(QStringLiteral("resource-attributes/file-name/text()"));
         query.evaluateTo(&fileName);
         fileName = fileName.trimmed();
 
@@ -338,7 +361,7 @@ QString EvernoteImportDialog::importAttachments(QString content,
     }
 
     // match media tags
-    QRegularExpression re("<en-media.+?type=\".+?\".*?>",
+    QRegularExpression re(QStringLiteral("<en-media.+?type=\".+?\".*?>"),
                           QRegularExpression::CaseInsensitiveOption);
     QRegularExpressionMatchIterator i = re.globalMatch(content);
     QStringList importedObjectIds;
@@ -349,8 +372,8 @@ QString EvernoteImportDialog::importAttachments(QString content,
         QString mediaTag = imageMatch.captured(0);
 
         // check for the hash
-        QRegularExpression re2("hash=\"(.+?)\"",
-                              QRegularExpression::CaseInsensitiveOption);
+        QRegularExpression re2(QStringLiteral("hash=\"(.+?)\""),
+                               QRegularExpression::CaseInsensitiveOption);
         QRegularExpressionMatch hashMatch = re2.match(mediaTag);
 
         if (!hashMatch.hasMatch()) {
@@ -369,7 +392,8 @@ QString EvernoteImportDialog::importAttachments(QString content,
         MediaFileData mediaFileData = mediaFileDataHash[objectId];
 
         // get the markdown code for the file data entry
-        QString markdownCode = getMarkdownForAttachmentFileData(mediaFileData);
+        QString markdownCode =
+            getMarkdownForAttachmentFileData(note, mediaFileData);
 
         if (!markdownCode.isEmpty()) {
             // replace media tag with markdown code
@@ -389,7 +413,8 @@ QString EvernoteImportDialog::importAttachments(QString content,
         MediaFileData mediaFileData = hashIterator.value();
 
         // get the markdown code for the file data entry
-        QString markdownCode = getMarkdownForAttachmentFileData(mediaFileData);
+        QString markdownCode =
+            getMarkdownForAttachmentFileData(note, mediaFileData);
 
         content += "\n" + markdownCode;
     }
@@ -397,59 +422,15 @@ QString EvernoteImportDialog::importAttachments(QString content,
     return content;
 }
 
-/**
- * Returns the markdown code for an image file data entry
- *
- * @param mediaFileData
- * @return
- */
-QString EvernoteImportDialog::getMarkdownForMediaFileData(
-        EvernoteImportDialog::MediaFileData &mediaFileData) {
-    QString data = mediaFileData.data;
-    QString imageSuffix = mediaFileData.suffix;
-
-    return Utils::Misc::importMediaFromBase64(data, imageSuffix);
-}
-
-/**
- * Returns the markdown code for an attachment file data entry
- *
- * @param mediaFileData
- * @return
- */
-QString EvernoteImportDialog::getMarkdownForAttachmentFileData(
-        EvernoteImportDialog::MediaFileData &mediaFileData) {
-    QString data = mediaFileData.data;
-    QString suffix = mediaFileData.suffix;
-    QString fileName = mediaFileData.fileName;
-
-    // create a temporary file for the attachment
-    QTemporaryFile *tempFile = new QTemporaryFile(
-            QDir::tempPath() + QDir::separator() + "media-XXXXXX." + suffix);
-
-    if (!tempFile->open()) {
-        return "";
-    }
-
-    // write file data to the temporary file
-    tempFile->write(QByteArray::fromBase64(data.toLatin1()));
-
-    // store the temporary file in the media folder and return the
-    // markdown code
-    QString markdownCode = Note::getInsertAttachmentMarkdown(tempFile,
-                                                             fileName);
-    return markdownCode;
-}
-
 /**
  * Imports the notes from the XML in data
  *
  * @param data
  */
-void EvernoteImportDialog::importNotes(QString data) {
+void EvernoteImportDialog::importNotes(const QString &data) {
     QXmlQuery query;
     query.setFocus(data);
-    query.setQuery("en-export/note");
+    query.setQuery(QStringLiteral("en-export/note"));
 
     bool importMetaData = isMetaDataChecked();
 
@@ -457,66 +438,37 @@ void EvernoteImportDialog::importNotes(QString data) {
     if (query.isValid()) {
         query.evaluateTo(&result);
         NoteSubFolder noteSubFolder = NoteSubFolder::activeNoteSubFolder();
-        HTMLEntities htmlEntities;
 
         while (!result.next().isNull()) {
+            Note note = Note();
+            note.setNoteSubFolderId(noteSubFolder.getId());
+
             query.setFocus(result.current());
 
             QString title;
-            query.setQuery("title/text()");
+            query.setQuery(QStringLiteral("title/text()"));
             query.evaluateTo(&title);
             title = title.trimmed();
 
             QString content;
-            query.setQuery("content/text()");
+            query.setQuery(QStringLiteral("content/text()"));
 
             // content seems to be html encoded
             query.evaluateTo(&content);
 
-            content.replace("\\\"", "\"");
-
-            // decode HTML entities
-            content = htmlEntities.decodeHtmlEntities(content);
-
-            // add a newline in front of lists
-//            content.replace(QRegularExpression("<ul.*?>"), "\n<ul>");
-//            content.replace(QRegularExpression("<ol.*?>"), "\n<ol>");
-
-            // remove web-clip code
-//            content.remove("<div style=\"-evernote-webclip:true;\">");
-
-            // replace code blocks
-            content.replace(QRegularExpression(
-                    R"(<div style="box-sizing.+?-en-codeblock:\s*true;"><div>(.+?)<\/div><\/div>)",
-                    QRegularExpression::MultilineOption),
-                            "\n```\n\\1\n```\n");
-            content.replace(QRegularExpression(
-                    R"(<div style="-en-codeblock:\s*true;.+?"><div>(.+?)<\/div><\/div>)",
-                    QRegularExpression::MultilineOption),
-                            "\n```\n\\1\n```\n");
-
-            // add a linebreak instead of div-containers
-            content.replace(QRegularExpression("<\\/div>"), "\n");
-
-            // convert html tags to markdown
-            content = Utils::Misc::htmlToMarkdown(content);
+            Utils::Misc::transformEvernoteImportText(content);
 
             if (ui->imageImportCheckBox->isChecked()) {
                 // import images
-                content = importImages(content, query);
+                content = importImages(note, std::move(content), query);
             }
 
             if (ui->attachmentImportCheckBox->isChecked()) {
                 // import attachments
-                content = importAttachments(content, query);
+                content = importAttachments(note, std::move(content), query);
             }
 
-            // remove all html tags
-            content.remove(QRegularExpression("<.+?>"));
-
-            // remove multiple \n
-            content.replace(QRegularExpression("\n\n+"), "\n\n");
-            content.replace(QRegularExpression("\n\n\\s+"), "\n\n");
+            Utils::Misc::cleanupEvernoteImportText(content);
 
 #ifdef Q_OS_WIN32
             // removing or replacing some characters that are asking for
@@ -537,17 +489,16 @@ void EvernoteImportDialog::importNotes(QString data) {
                 noteText += generateMetaDataMarkdown(query);
             }
 
-            noteText += content;
+            noteText += content.trimmed();
 
-            Note note = Note();
-//            note.setName(title);
+            //            note.setName(title);
             note.setNoteText(noteText);
 
             // in case the user enabled that the filename can be different
             // from the note name
+            // Attention: may already store the note
             note.handleNoteTextFileName();
 
-            note.setNoteSubFolderId(noteSubFolder.getId());
             note.store();
             note.storeNoteTextFileToDisk();
 
@@ -572,7 +523,7 @@ void EvernoteImportDialog::importNotes(QString data) {
  * @param note
  */
 void EvernoteImportDialog::tagNote(QXmlQuery &query, Note &note) {
-    query.setQuery("tag");
+    query.setQuery(QStringLiteral("tag"));
     QXmlResultItems result;
     query.evaluateTo(&result);
 
@@ -580,7 +531,7 @@ void EvernoteImportDialog::tagNote(QXmlQuery &query, Note &note) {
         query.setFocus(result.current());
 
         QString tagName;
-        query.setQuery("text()");
+        query.setQuery(QStringLiteral("text()"));
         query.evaluateTo(&tagName);
         tagName = tagName.trimmed();
 
@@ -598,6 +549,48 @@ void EvernoteImportDialog::tagNote(QXmlQuery &query, Note &note) {
     }
 }
 
+/**
+ * Generates the metadata markdown table for a note
+ */
+QString EvernoteImportDialog::generateMetaDataMarkdown(QXmlQuery query) {
+    QString resultText;
+    QString tableText;
+    QList<QTreeWidgetItem *> items = ui->metaDataTreeWidget->findItems(
+        QStringLiteral("*"),
+        Qt::MatchWrap | Qt::MatchWildcard | Qt::MatchRecursive);
+
+    Q_FOREACH (QTreeWidgetItem *item, items) {
+        if (item->checkState(0) != Qt::Checked) {
+            continue;
+        }
+
+        QString name = item->text(0);
+        QString attributeName = item->data(0, Qt::UserRole).toString();
+
+        QString attribute;
+        query.setQuery(attributeName + QStringLiteral("/text()"));
+        query.evaluateTo(&attribute);
+        attribute = attribute.trimmed();
+
+        if (attribute.isEmpty()) {
+            continue;
+        }
+
+        tableText += QStringLiteral("| ") + name + (" | ") + attribute +
+                     QStringLiteral(" |\n");
+    }
+
+    if (!tableText.isEmpty()) {
+        resultText = "| " + tr("Attribute") + " | " + tr("Value") +
+                     " |\n"
+                     "|---|---|\n" +
+                     tableText;
+    }
+
+    return resultText + QStringLiteral("\n");
+}
+#endif
+
 /**
  * Adds a metadata tree widget item
  *
@@ -607,9 +600,8 @@ void EvernoteImportDialog::tagNote(QXmlQuery &query, Note &note) {
  * @return
  */
 QTreeWidgetItem *EvernoteImportDialog::addMetaDataTreeWidgetItem(
-        QString name,
-        QString attributeName,
-        QTreeWidgetItem *parentItem) {
+    const QString &name, const QString &attributeName,
+    QTreeWidgetItem *parentItem) {
     auto *item = new QTreeWidgetItem();
     item->setText(0, name);
 
@@ -622,11 +614,13 @@ QTreeWidgetItem *EvernoteImportDialog::addMetaDataTreeWidgetItem(
         item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
 
         QSettings settings;
-        auto metaDataUnCheckedList = settings.value(
-                "EvernoteImport/MetaDataUnCheckedList").toStringList();
-        item->setCheckState(0,
-                metaDataUnCheckedList.contains(attributeName) ?
-                Qt::Unchecked : Qt::Checked);
+        auto metaDataUnCheckedList =
+            settings
+                .value(QStringLiteral("EvernoteImport/MetaDataUnCheckedList"))
+                .toStringList();
+        item->setCheckState(0, metaDataUnCheckedList.contains(attributeName)
+                                   ? Qt::Unchecked
+                                   : Qt::Checked);
 
         parentItem->addChild(item);
     }
@@ -638,42 +632,58 @@ QTreeWidgetItem *EvernoteImportDialog::addMetaDataTreeWidgetItem(
  * Setup the metadata tree widget items
  */
 void EvernoteImportDialog::setupMetaDataTreeWidgetItems() {
-    auto *basicAttributesItem = addMetaDataTreeWidgetItem(
-            tr("Basic attributes"));
-    addMetaDataTreeWidgetItem(tr("Created date"), "created",
-            basicAttributesItem);
-    addMetaDataTreeWidgetItem(tr("Updated date"), "updated",
-            basicAttributesItem);
+    auto *basicAttributesItem =
+        addMetaDataTreeWidgetItem(tr("Basic attributes"));
+    addMetaDataTreeWidgetItem(tr("Created date"), QStringLiteral("created"),
+                              basicAttributesItem);
+    addMetaDataTreeWidgetItem(tr("Updated date"), QStringLiteral("updated"),
+                              basicAttributesItem);
 
     auto *noteAttributesItem = addMetaDataTreeWidgetItem(tr("Note attributes"));
     addMetaDataTreeWidgetItem(tr("Subject date"),
-            "note-attributes/subject-date", noteAttributesItem);
+                              QStringLiteral("note-attributes/subject-date"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Latitude"),
-            "note-attributes/latitude", noteAttributesItem);
+                              QStringLiteral("note-attributes/latitude"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Longitude"),
-            "note-attributes/longitude", noteAttributesItem);
+                              QStringLiteral("note-attributes/longitude"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Altitude"),
-            "note-attributes/altitude", noteAttributesItem);
+                              QStringLiteral("note-attributes/altitude"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Author"),
-            "note-attributes/author", noteAttributesItem);
+                              QStringLiteral("note-attributes/author"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Source"),
-            "note-attributes/source", noteAttributesItem);
+                              QStringLiteral("note-attributes/source"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Source URL"),
-            "note-attributes/source-url", noteAttributesItem);
-    addMetaDataTreeWidgetItem(tr("Source application"),
-            "note-attributes/source-application", noteAttributesItem);
+                              QStringLiteral("note-attributes/source-url"),
+                              noteAttributesItem);
+    addMetaDataTreeWidgetItem(
+        tr("Source application"),
+        QStringLiteral("note-attributes/source-application"),
+        noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Reminder order"),
-            "note-attributes/reminder-order", noteAttributesItem);
+                              QStringLiteral("note-attributes/reminder-order"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Reminder time"),
-            "note-attributes/reminder-time", noteAttributesItem);
-    addMetaDataTreeWidgetItem(tr("Reminder done time"),
-            "note-attributes/reminder-done-time", noteAttributesItem);
+                              QStringLiteral("note-attributes/reminder-time"),
+                              noteAttributesItem);
+    addMetaDataTreeWidgetItem(
+        tr("Reminder done time"),
+        QStringLiteral("note-attributes/reminder-done-time"),
+        noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Place name"),
-            "note-attributes/place-name", noteAttributesItem);
+                              QStringLiteral("note-attributes/place-name"),
+                              noteAttributesItem);
     addMetaDataTreeWidgetItem(tr("Content class"),
-            "note-attributes/content-class", noteAttributesItem);
-    addMetaDataTreeWidgetItem(tr("Application data"),
-            "note-attributes/application-data", noteAttributesItem);
+                              QStringLiteral("note-attributes/content-class"),
+                              noteAttributesItem);
+    addMetaDataTreeWidgetItem(
+        tr("Application data"),
+        QStringLiteral("note-attributes/application-data"), noteAttributesItem);
 }
 
 /**
@@ -681,21 +691,21 @@ void EvernoteImportDialog::setupMetaDataTreeWidgetItems() {
  */
 void EvernoteImportDialog::storeMetaDataTreeWidgetItemsCheckedState() {
     QList<QTreeWidgetItem *> items = ui->metaDataTreeWidget->findItems(
-            QString("*"), Qt::MatchWrap | Qt::MatchWildcard |
-                          Qt::MatchRecursive);
+        QStringLiteral("*"),
+        Qt::MatchWrap | Qt::MatchWildcard | Qt::MatchRecursive);
     QSettings settings;
     QStringList metaDataUnCheckedList;
 
-    Q_FOREACH(QTreeWidgetItem *item, items) {
-            QString attributeName = item->data(0, Qt::UserRole).toString();
+    Q_FOREACH (QTreeWidgetItem *item, items) {
+        QString attributeName = item->data(0, Qt::UserRole).toString();
 
-            if (item->checkState(0) != Qt::Checked) {
-                metaDataUnCheckedList << attributeName;
-            }
+        if (item->checkState(0) != Qt::Checked) {
+            metaDataUnCheckedList << attributeName;
         }
+    }
 
-    settings.setValue("EvernoteImport/MetaDataUnCheckedList",
-            metaDataUnCheckedList);
+    settings.setValue(QStringLiteral("EvernoteImport/MetaDataUnCheckedList"),
+                      metaDataUnCheckedList);
 }
 
 /**
@@ -703,55 +713,16 @@ void EvernoteImportDialog::storeMetaDataTreeWidgetItemsCheckedState() {
  */
 bool EvernoteImportDialog::isMetaDataChecked() {
     QList<QTreeWidgetItem *> items = ui->metaDataTreeWidget->findItems(
-            QString("*"), Qt::MatchWrap | Qt::MatchWildcard |
-                          Qt::MatchRecursive);
+        QStringLiteral("*"),
+        Qt::MatchWrap | Qt::MatchWildcard | Qt::MatchRecursive);
 
-    Q_FOREACH(QTreeWidgetItem *item, items) {
-            if (item->checkState(0) == Qt::Checked) {
-                return true;
-            }
+    Q_FOREACH (QTreeWidgetItem *item, items) {
+        if (item->checkState(0) == Qt::Checked) {
+            return true;
         }
-
-    return false;
-}
-
-/**
- * Generates the metadata markdown table for a note
- */
-QString EvernoteImportDialog::generateMetaDataMarkdown(QXmlQuery query) {
-    QString resultText;
-    QString tableText;
-    QList<QTreeWidgetItem *> items = ui->metaDataTreeWidget->findItems(
-            QString("*"), Qt::MatchWrap | Qt::MatchWildcard |
-                          Qt::MatchRecursive);
-
-    Q_FOREACH(QTreeWidgetItem *item, items) {
-            if (item->checkState(0) != Qt::Checked) {
-                continue;
-            }
-
-            QString name = item->text(0);
-            QString attributeName = item->data(0, Qt::UserRole).toString();
-
-            QString attribute;
-            query.setQuery(attributeName + "/text()");
-            query.evaluateTo(&attribute);
-            attribute = attribute.trimmed();
-
-            if (attribute.isEmpty()) {
-                continue;
-            }
-
-            tableText += "| " + name + " | " + attribute + " |\n";
-        }
-
-    if (!tableText.isEmpty()) {
-        resultText = "| " + tr("Attribute") + " | " + tr("Value") + " |\n"
-                     "|---|---|\n" +
-                     tableText;
     }
 
-    return resultText;
+    return false;
 }
 
 /**
@@ -775,10 +746,57 @@ void EvernoteImportDialog::on_importButton_clicked() {
 
     QString data = file.readAll();
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     QCoreApplication::processEvents();
     initNoteCount(data);
     QCoreApplication::processEvents();
     importNotes(data);
+#endif
 
     ui->importButton->setEnabled(true);
 }
+
+/**
+ * Returns the markdown code for an image file data entry
+ *
+ * @param mediaFileData
+ * @return
+ */
+QString EvernoteImportDialog::getMarkdownForMediaFileData(
+    Note note, const EvernoteImportDialog::MediaFileData &mediaFileData) {
+    QString data = mediaFileData.data;
+    QString imageSuffix = mediaFileData.suffix;
+
+    return note.importMediaFromBase64(data, imageSuffix);
+}
+
+/**
+ * Returns the markdown code for an attachment file data entry
+ *
+ * @param mediaFileData
+ * @return
+ */
+QString EvernoteImportDialog::getMarkdownForAttachmentFileData(
+    Note note, const EvernoteImportDialog::MediaFileData &mediaFileData) {
+    QString data = mediaFileData.data;
+    QString suffix = mediaFileData.suffix;
+    QString fileName = mediaFileData.fileName;
+
+    // create a temporary file for the attachment
+    auto *tempFile =
+        new QTemporaryFile(QDir::tempPath() + QDir::separator() +
+                           QStringLiteral("media-XXXXXX.") + suffix);
+
+    if (!tempFile->open()) {
+        return QString();
+    }
+
+    // write file data to the temporary file
+    tempFile->write(QByteArray::fromBase64(data.toLatin1()));
+
+    // store the temporary file in the media folder and return the
+    // markdown code
+    QString markdownCode = note.getInsertAttachmentMarkdown(tempFile, fileName);
+
+    return markdownCode;
+}
