@@ -1,19 +1,19 @@
 #include "passworddialog.h"
+
 #include <QPushButton>
+
 #include "ui_passworddialog.h"
 
-PasswordDialog::PasswordDialog(
-        QWidget *parent,
-        QString labelText,
-        bool doubleEnterPassword) :
-        MasterDialog(parent),
-        ui(new Ui::PasswordDialog) {
+PasswordDialog::PasswordDialog(QWidget *parent, const QString &labelText,
+                               bool doubleEnterPassword)
+    : MasterDialog(parent), ui(new Ui::PasswordDialog) {
     _doubleEnterPassword = doubleEnterPassword;
 
     ui->setupUi(this);
 
     ui->passwordLineEdit2->setVisible(doubleEnterPassword);
-    ui->buttonBox->button( QDialogButtonBox::Ok )->setEnabled(!doubleEnterPassword);
+    ui->buttonBox->button(QDialogButtonBox::Ok)
+        ->setEnabled(!doubleEnterPassword);
     ui->errorLabel->setVisible(false);
 
     if (!labelText.isEmpty()) {
@@ -21,13 +21,9 @@ PasswordDialog::PasswordDialog(
     }
 }
 
-PasswordDialog::~PasswordDialog() {
-    delete ui;
-}
+PasswordDialog::~PasswordDialog() { delete ui; }
 
-QString PasswordDialog::password() {
-    return ui->passwordLineEdit->text();
-}
+QString PasswordDialog::password() { return ui->passwordLineEdit->text(); }
 
 void PasswordDialog::on_passwordLineEdit_textChanged(const QString &arg1) {
     Q_UNUSED(arg1);
@@ -48,9 +44,9 @@ void PasswordDialog::on_passwordLineEdit2_textChanged(const QString &arg1) {
 bool PasswordDialog::checkIfPasswordsAreEqual() {
     bool equal = ui->passwordLineEdit->text() == ui->passwordLineEdit2->text();
 
-    ui->errorLabel->setVisible(!equal && !ui->passwordLineEdit2->text()
-            .isEmpty());
-    ui->buttonBox->button( QDialogButtonBox::Ok )->setEnabled(equal);
+    ui->errorLabel->setVisible(!equal &&
+                               !ui->passwordLineEdit2->text().isEmpty());
+    ui->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(equal);
 
     return equal;
 }
