@@ -1,40 +1,45 @@
-#include <QtNetwork/QNetworkRequest>
-#include <QtWidgets/QSplitter>
-#include <QtCore/QSettings>
-#include <QJsonDocument>
-#include <QtCore/QJsonObject>
-#include <QtCore/QJsonArray>
-#include <entities/script.h>
-#include <QtCore/QFile>
-#include <utils/misc.h>
-#include <QtWidgets/QMessageBox>
-#include <QScrollBar>
-#include <QtMath>
-#include <services/metricsservice.h>
-#include <libraries/versionnumber/versionnumber.h>
-#include <utils/gui.h>
 #include "scriptrepositorydialog.h"
-#include "ui_scriptrepositorydialog.h"
+
+#include <libraries/versionnumber/versionnumber.h>
+#include <services/metricsservice.h>
+#include <utils/gui.h>
+#include <utils/misc.h>
+
+#include <QDebug>
+#include <QJsonDocument>
+#include <QNetworkAccessManager>
+#include <QNetworkReply>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
+#include <QScrollBar>
+#include <QtCore/QFile>
+#include <QtCore/QJsonArray>
+#include <QtCore/QJsonObject>
+#include <QtCore/QSettings>
+#include <QtMath>
+#include <QtNetwork/QNetworkRequest>
+#include <QtWidgets/QMessageBox>
+#include <QtWidgets/QSplitter>
+
+#include "ui_scriptrepositorydialog.h"
 
 ScriptRepositoryDialog::ScriptRepositoryDialog(QWidget *parent,
-                                               bool checkForUpdates) :
-    MasterDialog(parent),
-    ui(new Ui::ScriptRepositoryDialog) {
+                                               bool checkForUpdates)
+    : MasterDialog(parent), ui(new Ui::ScriptRepositoryDialog) {
     ui->setupUi(this);
     setupMainSplitter();
 
-    _networkManager = new QNetworkAccessManager();
-    QObject::connect(_networkManager, SIGNAL(finished(QNetworkReply *)),
-                     this, SLOT(slotReplyFinished(QNetworkReply *)));
+    _networkManager = new QNetworkAccessManager(this);
+    QObject::connect(_networkManager, SIGNAL(finished(QNetworkReply *)), this,
+                     SLOT(slotReplyFinished(QNetworkReply *)));
 
-    _codeSearchUrl = "https://api.github.com/search/code";
+    _codeSearchUrl = QLatin1String("https://api.github.com/search/code");
     _rawContentUrlPrefix = Script::ScriptRepositoryRawContentUrlPrefix;
     _checkForUpdates = checkForUpdates;
     _searchString.clear();
     _page = 1;
     _totalCount = 0;
+    _lastInstalledScript = Script();
 
     ui->downloadProgressBar->hide();
     ui->loadMoreScriptsButton->hide();
@@ -49,8 +54,8 @@ ScriptRepositoryDialog::ScriptRepositoryDialog(QWidget *parent,
         searchForUpdates();
     } else {
         QObject::connect(ui->scriptTreeWidget->verticalScrollBar(),
-                         SIGNAL(valueChanged(int)),
-                         this, SLOT(scriptTreeWidgetSliderValueChanged(int)));
+                         SIGNAL(valueChanged(int)), this,
+                         SLOT(scriptTreeWidgetSliderValueChanged(int)));
 
         searchScript();
     }
@@ -81,11 +86,11 @@ void ScriptRepositoryDialog::loadMoreItems() {
 
 /**
  * Checks if there are more items to load
- * 
+ *
  * @return
  */
 bool ScriptRepositoryDialog::hasMoreItems() const {
-    bool hasMoreItems = qCeil((qreal) _totalCount / _itemsPerPage) > _page;
+    bool hasMoreItems = qCeil((qreal)_totalCount / _itemsPerPage) > _page;
     return hasMoreItems;
 }
 
@@ -108,18 +113,22 @@ void ScriptRepositoryDialog::searchScript(int page) {
     }
 
     QString query = QUrl::toPercentEncoding(_searchString);
-    QUrl url(_codeSearchUrl +"?q=" + query + "+in:file+language:json"
-                     "+repo:qownnotes/scripts&page=" + QString::number(page));
+    QUrl url(_codeSearchUrl + "?q=" + query +
+             "+in:file+language:json"
+             "+repo:qownnotes/scripts&page=" +
+             QString::number(page));
     QNetworkRequest networkRequest(url);
     _page = page;
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
-    networkRequest.setAttribute(
-            QNetworkRequest::FollowRedirectsAttribute, true);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
+                                true);
 #endif
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     // try to ensure the network is accessible
     _networkManager->setNetworkAccessible(QNetworkAccessManager::Accessible);
+#endif
 
     _networkManager->get(networkRequest);
 
@@ -135,24 +144,27 @@ void ScriptRepositoryDialog::searchForUpdates() {
     ui->scriptTreeWidget->clear();
     enableOverview(true);
 
-    Q_FOREACH(Script script, Script::fetchAll()) {
-            if (!script.isScriptFromRepository()) {
-                continue;
-            }
+    Q_FOREACH (Script script, Script::fetchAll()) {
+        if (!script.isScriptFromRepository()) {
+            continue;
+        }
 
-            QUrl url = script.repositoryInfoJsonUrl();
-            QNetworkRequest networkRequest(url);
+        QUrl url = script.repositoryInfoJsonUrl();
+        QNetworkRequest networkRequest(url);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
-            networkRequest.setAttribute(
-                    QNetworkRequest::FollowRedirectsAttribute, true);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+        networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
+                                    true);
 #endif
 
-            // try to ensure the network is accessible
-            _networkManager->setNetworkAccessible(
-                    QNetworkAccessManager::Accessible);
-            _networkManager->get(networkRequest);
-        }
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+        // try to ensure the network is accessible
+        _networkManager->setNetworkAccessible(
+            QNetworkAccessManager::Accessible);
+#endif
+
+        _networkManager->get(networkRequest);
+    }
 }
 
 /**
@@ -172,17 +184,19 @@ void ScriptRepositoryDialog::slotReplyFinished(QNetworkReply *reply) {
 
     qDebug() << "Reply from " << urlPath;
 
-    if (urlPath.endsWith("/search/code")) {
+    if (urlPath.endsWith(QLatin1String("/search/code"))) {
         QByteArray arr = reply->readAll();
         qDebug() << "Reply from code search";
 
         parseCodeSearchReply(arr);
-    } else if (urlPath.startsWith("/qownnotes/scripts/master")) {
+    } else if (urlPath.startsWith(QLatin1String("/qownnotes/scripts/master"))) {
         QByteArray arr = reply->readAll();
         qDebug() << "Reply from info.qml request";
 
         parseInfoQMLReply(arr);
     }
+
+    reply->deleteLater();
 }
 
 /**
@@ -194,8 +208,8 @@ void ScriptRepositoryDialog::slotReplyFinished(QNetworkReply *reply) {
 void ScriptRepositoryDialog::parseCodeSearchReply(const QByteArray &arr) {
     QJsonDocument jsonResponse = QJsonDocument::fromJson(arr);
     QJsonObject jsonObject = jsonResponse.object();
-    _totalCount = jsonObject.value("total_count").toInt();
-    QJsonArray items = jsonObject.value("items").toArray();
+    _totalCount = jsonObject.value(QStringLiteral("total_count")).toInt();
+    QJsonArray items = jsonObject.value(QStringLiteral("items")).toArray();
     ui->loadMoreScriptsButton->setVisible(hasMoreItems());
 
     if (_page == 1) {
@@ -204,40 +218,43 @@ void ScriptRepositoryDialog::parseCodeSearchReply(const QByteArray &arr) {
 
     enableOverview(_page == 1);
 
-    foreach(const QJsonValue &value, items) {
-            QJsonObject obj = value.toObject();
-            QString path = obj["path"].toString();
-            qDebug() << __func__ << " - 'path': " << path;
+    foreach (const QJsonValue &value, items) {
+        QJsonObject obj = value.toObject();
+        QString path = obj[QStringLiteral("path")].toString();
+        qDebug() << __func__ << " - 'path': " << path;
 
-            QRegularExpressionMatch match =
-                    QRegularExpression("(.+)\\/info\\.json").match(path);
+        QRegularExpressionMatch match =
+            QRegularExpression(QStringLiteral("(.+)\\/info\\.json"))
+                .match(path);
 
-            if (!match.hasMatch()) {
-                continue;
-            }
+        if (!match.hasMatch()) {
+            continue;
+        }
 
-            QString identifier = match.captured(1);
-            qDebug() << "Found script: " + identifier;
+        QString identifier = match.captured(1);
+        qDebug() << "Found script: " + identifier;
 
-            // we are ignoring the example-script
-            if (identifier == "example-script") {
-                continue;
-            }
+        // we are ignoring the example-script
+        if (identifier == QLatin1String("example-script")) {
+            continue;
+        }
 
-            QUrl url(_rawContentUrlPrefix + path);
-            QNetworkRequest networkRequest(url);
+        QUrl url(_rawContentUrlPrefix + path);
+        QNetworkRequest networkRequest(url);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
-            networkRequest.setAttribute(
-                    QNetworkRequest::FollowRedirectsAttribute, true);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+        networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
+                                    true);
 #endif
 
-            // try to ensure the network is accessible
-            _networkManager->setNetworkAccessible(
-                    QNetworkAccessManager::Accessible);
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+        // try to ensure the network is accessible
+        _networkManager->setNetworkAccessible(
+            QNetworkAccessManager::Accessible);
+#endif
 
-            _networkManager->get(networkRequest);
-        }
+        _networkManager->get(networkRequest);
+    }
 
     ui->downloadProgressBar->hide();
 }
@@ -247,7 +264,7 @@ void ScriptRepositoryDialog::parseCodeSearchReply(const QByteArray &arr) {
  *
  * @param arr
  */
-void ScriptRepositoryDialog::parseInfoQMLReply(const QByteArray &arr) const {
+void ScriptRepositoryDialog::parseInfoQMLReply(const QByteArray &arr) {
     QJsonDocument jsonResponse = QJsonDocument::fromJson(arr);
     QJsonObject jsonObject = jsonResponse.object();
     ScriptInfoJson infoJson(jsonObject);
@@ -268,25 +285,27 @@ void ScriptRepositoryDialog::parseInfoQMLReply(const QByteArray &arr) const {
             return;
         }
 
+        emit updateFound();
+
         ui->selectFrame->show();
     }
 
     QString jsonData = QString(arr);
 
     // check if script item already exists in tree widget
-    if (Utils::Gui::userDataInTreeWidgetExists(
-            ui->scriptTreeWidget, jsonData)) {
+    if (Utils::Gui::userDataInTreeWidgetExists(ui->scriptTreeWidget,
+                                               jsonData)) {
         return;
     }
 
     QString name = infoJson.name;
 
-    QTreeWidgetItem *item = new QTreeWidgetItem();
+    auto *item = new QTreeWidgetItem();
     item->setText(0, name);
     item->setData(0, Qt::UserRole, jsonData);
 
     if (!infoJson.platformSupported || !infoJson.appVersionSupported) {
-        item->setTextColor(0, QColor("#aaaaaa"));
+        item->setForeground(0, QColor("#aaaaaa"));
     }
 
     ui->scriptTreeWidget->addTopLevelItem(item);
@@ -294,7 +313,7 @@ void ScriptRepositoryDialog::parseInfoQMLReply(const QByteArray &arr) const {
 
     if (_page == 1) {
         ui->scriptTreeWidget->setCurrentItem(
-                ui->scriptTreeWidget->topLevelItem(0));
+            ui->scriptTreeWidget->topLevelItem(0));
     }
 }
 
@@ -302,15 +321,17 @@ void ScriptRepositoryDialog::parseInfoQMLReply(const QByteArray &arr) const {
  * Sets up the main splitter
  */
 void ScriptRepositoryDialog::setupMainSplitter() {
-    _mainSplitter = new QSplitter;
+    _mainSplitter = new QSplitter(this);
 
     _mainSplitter->addWidget(ui->selectFrame);
     _mainSplitter->addWidget(ui->infoFrame);
 
     // restore splitter sizes
     QSettings settings;
-    QByteArray state = settings.value(
-            "ScriptRepositoryDialog/mainSplitterState").toByteArray();
+    QByteArray state =
+        settings
+            .value(QStringLiteral("ScriptRepositoryDialog/mainSplitterState"))
+            .toByteArray();
     _mainSplitter->restoreState(state);
 
     ui->gridLayout->layout()->addWidget(_mainSplitter);
@@ -321,8 +342,9 @@ void ScriptRepositoryDialog::setupMainSplitter() {
  */
 void ScriptRepositoryDialog::storeSettings() {
     QSettings settings;
-    settings.setValue("ScriptRepositoryDialog/mainSplitterState",
-                      _mainSplitter->saveState());
+    settings.setValue(
+        QStringLiteral("ScriptRepositoryDialog/mainSplitterState"),
+        _mainSplitter->saveState());
 }
 
 /**
@@ -332,7 +354,7 @@ void ScriptRepositoryDialog::storeSettings() {
  * @param previous
  */
 void ScriptRepositoryDialog::on_scriptTreeWidget_currentItemChanged(
-        QTreeWidgetItem *current, QTreeWidgetItem *previous) {
+    QTreeWidgetItem *current, QTreeWidgetItem *previous) {
     Q_UNUSED(current);
     Q_UNUSED(previous);
 
@@ -360,19 +382,20 @@ void ScriptRepositoryDialog::reloadCurrentScriptInfo() {
     ui->minAppVersionLabel->setText(infoJson.minAppVersion);
     ui->minAppVersionLabel->setHidden(infoJson.minAppVersion.isEmpty());
     ui->minAppVersionHeadlineLabel->setVisible(
-            ui->minAppVersionLabel->isVisible());
+        ui->minAppVersionLabel->isVisible());
     ui->descriptionLabel->setText(infoJson.description);
     ui->authorLabel->setText(infoJson.richAuthorText);
-    ui->authorHeadlineLabel->setText((infoJson.richAuthorList.count() > 1 ?
-                                        tr("Authors") : tr("Author")) + ":");
+    ui->authorHeadlineLabel->setText(
+        (infoJson.richAuthorList.count() > 1 ? tr("Authors") : tr("Author")) +
+        ":");
     ui->platformLabel->setText(infoJson.richPlatformText);
-    ui->platformHeadlineLabel->setText((infoJson.platformList.count() > 1 ?
-                                        tr("Supported platforms") :
-                                        tr("Supported platform")) + ":");
+    ui->platformHeadlineLabel->setText((infoJson.platformList.count() > 1
+                                            ? tr("Supported platforms")
+                                            : tr("Supported platform")) +
+                                       ":");
     ui->repositoryLinkLabel->setText(
-            "<a href=\"https://github.com/qownnotes/scripts/tree/master/" +
-                    infoJson.identifier + "\">" + tr("Open repository") +
-                    "</a>");
+        "<a href=\"https://github.com/qownnotes/scripts/tree/master/" +
+        infoJson.identifier + "\">" + tr("Open repository") + "</a>");
 
     Script script = Script::fetchByIdentifier(infoJson.identifier);
     if (script.isFetched()) {
@@ -406,8 +429,8 @@ void ScriptRepositoryDialog::reloadCurrentScriptInfo() {
  * @return
  */
 QJsonObject ScriptRepositoryDialog::getCurrentInfoJsonObject() {
-    QJsonDocument jsonResponse = QJsonDocument::fromJson(
-            getCurrentInfoJsonString().toUtf8());
+    QJsonDocument jsonResponse =
+        QJsonDocument::fromJson(getCurrentInfoJsonString().toUtf8());
     QJsonObject jsonObject = jsonResponse.object();
 
     return jsonObject;
@@ -422,7 +445,7 @@ QString ScriptRepositoryDialog::getCurrentInfoJsonString() {
     QTreeWidgetItem *item = ui->scriptTreeWidget->currentItem();
 
     if (item == Q_NULLPTR) {
-        return "";
+        return QString();
     }
 
     QString data = item->data(0, Qt::UserRole).toString();
@@ -439,7 +462,8 @@ void ScriptRepositoryDialog::on_installButton_clicked() {
         return;
     }
 
-    QString identifier = jsonObject.value("identifier").toString();
+    QString identifier =
+        jsonObject.value(QStringLiteral("identifier")).toString();
 
     if (identifier.isEmpty()) {
         return;
@@ -450,21 +474,21 @@ void ScriptRepositoryDialog::on_installButton_clicked() {
     QString scriptName = infoJson.script;
 
     // check if platform is supported
-    if (!infoJson.platformSupported && QMessageBox::information(
+    if (!infoJson.platformSupported &&
+        QMessageBox::information(
             this, tr("Platform not supported!"),
             tr("Your platform is not supported by this script!\n"
-                       "Do you want to install it anyway?"),
-            tr("Install"), tr("Cancel"), QString::null,
-            0, 1) != 0) {
+               "Do you want to install it anyway?"),
+            tr("Install"), tr("Cancel"), QString(), 0, 1) != 0) {
         return;
     }
 
     // check if app version is supported
     if (!infoJson.appVersionSupported) {
         QMessageBox::information(
-                this, tr("Update app"),
-                tr("Please don't forget to update your installation of "
-                           "QOwnNotes to make this script work!"));
+            this, tr("Update app"),
+            tr("Please don't forget to update your installation of "
+               "QOwnNotes to make this script work!"));
     }
 
     ui->installButton->setEnabled(false);
@@ -494,7 +518,7 @@ void ScriptRepositoryDialog::on_installButton_clicked() {
 
     // download the script
     if (!url.isEmpty()) {
-        QFile *file = new QFile(scriptPath);
+        auto *file = new QFile(scriptPath);
         qDebug() << "Downloading: " << url;
         filesWereDownloaded = Utils::Misc::downloadUrlToFile(url, file);
         file->close();
@@ -504,22 +528,22 @@ void ScriptRepositoryDialog::on_installButton_clicked() {
     if (filesWereDownloaded) {
         ScriptInfoJson infoJson = script.getScriptInfoJson();
         foreach (QString resourceFileName, infoJson.resources) {
-                QUrl resourceUrl = script.remoteFileUrl(resourceFileName);
-                qDebug() << "Downloading: " << resourceUrl;
+            QUrl resourceUrl = script.remoteFileUrl(resourceFileName);
+            qDebug() << "Downloading: " << resourceUrl;
 
-                QFile *file = new QFile(scriptRepositoryPath + "/" +
-                                                resourceFileName);
+            auto *file =
+                new QFile(scriptRepositoryPath + "/" + resourceFileName);
 
-                if (!Utils::Misc::downloadUrlToFile(resourceUrl, file)) {
-                    filesWereDownloaded = false;
-                }
-
-                file->close();
-
-                if (!filesWereDownloaded) {
-                    break;
-                }
+            if (!Utils::Misc::downloadUrlToFile(resourceUrl, file)) {
+                filesWereDownloaded = false;
             }
+
+            file->close();
+
+            if (!filesWereDownloaded) {
+                break;
+            }
+        }
     }
 
     ui->installButton->setEnabled(true);
@@ -527,24 +551,25 @@ void ScriptRepositoryDialog::on_installButton_clicked() {
     if (filesWereDownloaded) {
         script.store();
         MetricsService::instance()->sendVisitIfEnabled(
-                "script-repository/install/" + identifier);
+            "script-repository/install/" + identifier);
         reloadCurrentScriptInfo();
+        _lastInstalledScript = script;
 
         Utils::Gui::information(this, tr("Install successful"),
                                 tr("The script was successfully installed!"),
-                                "script-install-successful");
+                                QStringLiteral("script-install-successful"));
 
         if (_checkForUpdates) {
             searchForUpdates();
         }
     } else {
         QMessageBox::warning(this, tr("Download failed"),
-                                 tr("The script could not be downloaded!"));
+                             tr("The script could not be downloaded!"));
     }
 }
 
 void ScriptRepositoryDialog::on_searchScriptEdit_textChanged(
-        const QString &arg1) {
+    const QString &arg1) {
     // list all scripts again if the search bar was cleared
     if (!_checkForUpdates && arg1.isEmpty()) {
         searchScript();
@@ -554,3 +579,7 @@ void ScriptRepositoryDialog::on_searchScriptEdit_textChanged(
 void ScriptRepositoryDialog::on_loadMoreScriptsButton_clicked() {
     loadMoreItems();
 }
+
+Script ScriptRepositoryDialog::getLastInstalledScript() {
+    return _lastInstalledScript;
+}
