@@ -469,13 +469,25 @@ bool UpdateDialog::initializeLinuxUpdateProcess(const QString &filePath) {
     // rename the new AppImage to the path of the current binary
     if (!updateFile.rename(appPath)) {
         QMessageBox::critical(0, tr("File error"),
-          tr("Your old QOwnNotes executable '%1' could not be overwritten be replaced "
+          tr("Your old QOwnNotes executable '%1' could not be replaced "
                 "by the new file '%2'! You need to replace it yourself.")
               .arg(appPath, filePath));
 
         return false;
     }
 
+    QFile appFile(appPath);
+
+    // make the new AppImage executable (2nd attempt)
+    if (!appFile.setPermissions(appFile.permissions() | QFileDevice::ExeOwner)) {
+        QMessageBox::critical(0, tr("Permission error"),
+                              tr("The app file '%1' could not be made executable! "
+                                 "You need to make it executable yourself.")
+                                  .arg(appPath));
+
+        return false;
+    }
+
     if (QMessageBox::information(
             this, tr("Restart application"),
             tr("You now can restart the application to complete the update process.") +
