@@ -1,6 +1,6 @@
 
 /*
- * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2022 Patrizio Bekerle -- <patrizio@bekerle.com>
  * Copyright (c) 2019-2021 Waqar Ahmed      -- <waqar.17a@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -558,7 +558,13 @@ void MarkdownHighlighter::highlightHeadline(const QString &text) {
             const auto state =
                 HighlighterState(HighlighterState::H1 + headingLevel - 1);
 
-            setFormat(0, text.length(), _formats[state]);
+            // Set styling of the "#"s to "masked syntax", but with the size of the heading
+            auto maskedFormat = _formats[MaskedSyntax];
+            maskedFormat.setFontPointSize(_formats[state].fontPointSize());
+            setFormat(0, headingLevel, maskedFormat);
+
+            // Set the styling of the rest of the heading
+            setFormat(headingLevel + 1, text.length() - 1 - headingLevel, _formats[state]);
 
             setCurrentBlockState(state);
             return;
@@ -636,7 +642,7 @@ void MarkdownHighlighter::highlightSubHeadline(const QString &text,
         setCurrentBlockState(HeadlineEnd);
 
         // we want to re-highlight the previous block
-        // this must not done directly, but with a queue, otherwise it
+        // this must not be done directly, but with a queue, otherwise it
         // will crash
         // setting the character format of the previous text, because this
         // causes text to be formatted the same way when writing after
@@ -912,11 +918,12 @@ void MarkdownHighlighter::highlightSyntax(const QString &text) {
         // check if we are at the beginning OR if this is the start of a word
         if (i == 0 || (!text.at(i - 1).isLetterOrNumber() &&
                        text.at(i-1) != QLatin1Char('_'))) {
-            const auto wordList = data.values(text.at(i).toLatin1());
-            for (const QLatin1String &word : wordList) {
+            auto it = data.find(text.at(i).toLatin1());
+            for (; it != data.end() && it.key() == text.at(i).toLatin1(); ++it) {
                 // we have a word match check
                 // 1. if we are at the end
                 // 2. if we have a complete word
+                const QLatin1String &word = it.value();
                 if (word == MH_SUBSTR(i, word.size()) &&
                     (i + word.size() == text.length() ||
                      (!text.at(i + word.size()).isLetterOrNumber() &&
@@ -1025,9 +1032,9 @@ void MarkdownHighlighter::highlightSyntax(const QString &text) {
 
         /* Highlight other stuff (preprocessor etc.) */
         if (i == 0 || !text.at(i - 1).isLetter()) {
-            const QList<QLatin1String> wordList =
-                others.values(text[i].toLatin1());
-            for (const QLatin1String &word : wordList) {
+            auto it = others.find(text.at(i).toLatin1());
+            for (; it != others.end() && it.key() == text.at(i).toLatin1(); ++it) {
+                const QLatin1String &word = it.value();
                 if (word == MH_SUBSTR(i, word.size()) &&
                     (i + word.size() == text.length() ||
                      !text.at(i + word.size()).isLetter())) {
@@ -1737,7 +1744,7 @@ void MarkdownHighlighter::highlightCheckbox(const QString &text, int curPos)
     const bool hasOpeningBracket = text.at(curPos + 2) == QLatin1Char('[');
     const bool hasClosingBracked = text.at(curPos + 4) == QLatin1Char(']');
     const QChar midChar = text.at(curPos + 3);
-    const bool hasXorSpace = midChar == QLatin1Char(' ') || midChar == QLatin1Char('x');
+    const bool hasXorSpace = midChar == QLatin1Char(' ') || midChar == QLatin1Char('x') || midChar == QLatin1Char('X');
     const bool hasDash = midChar == QLatin1Char('-');
 
     if (hasOpeningBracket && hasClosingBracked && (hasXorSpace | hasDash)) {
@@ -2282,6 +2289,7 @@ void MarkdownHighlighter::highlightEmAndStrong(const QString &text,
         if (startDelim.end == -1) continue;
 
         const auto &endDelim = delims.at(startDelim.end);
+        auto state = static_cast<HighlighterState>(currentBlockState());
 
         const bool isStrong =
             i > 0 && delims.at(i - 1).end == startDelim.end + 1 &&
@@ -2303,6 +2311,9 @@ void MarkdownHighlighter::highlightEmAndStrong(const QString &text,
                 QTextCharFormat fmt = QSyntaxHighlighter::format(k);
                 fmt.setFont(_formats[Bold].font());
 
+                if (_formats[state].fontPointSize() > 0)
+                    fmt.setFontPointSize(_formats[state].fontPointSize());
+
                 // if we are in plain text, use the format's specified color
                 if (fmt.foreground() == QTextCharFormat().foreground())
                     fmt.setForeground(_formats[Bold].foreground());
@@ -2343,6 +2354,9 @@ void MarkdownHighlighter::highlightEmAndStrong(const QString &text,
                 QTextCharFormat fmt = QSyntaxHighlighter::format(k);
                 fmt.setFont(_formats[Italic].font());
 
+                if (_formats[state].fontPointSize() > 0)
+                    fmt.setFontPointSize(_formats[state].fontPointSize());
+
                 if (fmt.foreground() == QTextCharFormat().foreground())
                     fmt.setForeground(_formats[Italic].foreground());
 
