@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2022 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -111,6 +111,12 @@ void QMarkdownTextEdit::setLineNumbersOtherLineColor(QColor color) {
     _lineNumArea->setOtherLineColor(std::move(color));
 }
 
+void QMarkdownTextEdit::setSearchWidgetDebounceDelay(uint debounceDelay)
+{
+    _debounceDelay = debounceDelay;
+    searchWidget()->setDebounceDelay(_debounceDelay);
+}
+
 /**
  * Enables or disables the markdown highlighting
  *
@@ -273,24 +279,6 @@ bool QMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
                 qApp->clipboard()->setText(text);
                 return true;
             }
-        } else if (keyEvent == QKeySequence::Paste) {
-            if (qApp->clipboard()->ownsClipboard()) {
-                // Do exact match
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-                bool matched = QRegExp(QStringLiteral("[^\n]*\n$")).exactMatch(qApp->clipboard()->text());
-#else
-                static const QRegularExpression re(QRegularExpression::anchoredPattern(QStringLiteral("[^\n]*\n$")));
-                bool matched = re.match(qApp->clipboard()->text()).hasMatch();
-#endif
-                if (!matched) {
-                    return QPlainTextEdit::eventFilter(obj, event);
-                }
-                QTextCursor cursor = this->textCursor();
-                if (!cursor.hasSelection()) {
-                    cursor.movePosition(QTextCursor::StartOfBlock);
-                    setTextCursor(cursor);
-                }
-            }
         } else if ((keyEvent->key() == Qt::Key_Down) &&
                    keyEvent->modifiers().testFlag(Qt::ControlModifier) &&
                    keyEvent->modifiers().testFlag(Qt::AltModifier)) {
@@ -1249,7 +1237,7 @@ QMap<QString, QString> QMarkdownTextEdit::parseMarkdownUrlsFromText(
 
     // match reference urls like this: [this url][1] with this later:
     // [1]: http://domain
-    regex = QRegularExpression(R"(\[(.*?)\]\[(.+?)\])");
+    regex = QRegularExpression(R"((\[.*?\]\[(.+?)\]))");
     iterator = regex.globalMatch(text);
     while (iterator.hasNext()) {
         QRegularExpressionMatch match = iterator.next();
@@ -1262,7 +1250,7 @@ QMap<QString, QString> QMarkdownTextEdit::parseMarkdownUrlsFromText(
         //                        "\\]: (.+?:\\/\\/.+)");
         QRegularExpression refRegExp(QStringLiteral("\\[") +
                                      QRegularExpression::escape(referenceId) +
-                                     QStringLiteral("\\]: (.+?)"));
+                                     QStringLiteral("\\]: (.+)"));
         QRegularExpressionMatch urlMatch = refRegExp.match(toPlainText());
 
         if (urlMatch.hasMatch()) {
@@ -1789,6 +1777,7 @@ void QMarkdownTextEdit::hideSearchWidget(bool reset) {
 
 void QMarkdownTextEdit::updateSettings() {
     // if true: centers the screen if cursor reaches bottom (but not top)
+    searchWidget()->setDebounceDelay(_debounceDelay);
     setCenterOnScroll(_centerCursor);
 }
 
