@@ -3,7 +3,6 @@
 #include <utils/gui.h>
 #include <utils/misc.h>
 #include <utils/schema.h>
-#include <widgets/logwidget.h>
 
 #include <QApplication>
 #include <QFileDialog>
@@ -105,6 +104,11 @@ bool mainStartupMisc(const QStringList &arguments) {
             "application and environment in GitHub Markdown and exits "
             "the application."));
     parser.addOption(dumpSettingsOption);
+    const QCommandLineOption versionOption(
+        QStringLiteral("version"),
+        QCoreApplication::translate(
+            "main", "Prints out the version number."));
+    parser.addOption(versionOption);
     const QCommandLineOption allowMultipleInstancesOption(
         QStringLiteral("allow-multiple-instances"),
         QCoreApplication::translate(
@@ -375,7 +379,7 @@ inline void setAppProperties(QCoreApplication &app, const QString &release,
 }
 
 int main(int argc, char *argv[]) {
-    // register NoteHistoryItem so we can store it to the settings
+    // register NoteHistoryItem, so we can store it to the settings
     // we need to do that before we are accessing QSettings or the
     // NoteHistoryItem instances in the settings will get destroyed
     qRegisterMetaTypeStreamOperators<NoteHistoryItem>("NoteHistoryItem");
@@ -443,6 +447,9 @@ int main(int argc, char *argv[]) {
             if (argc > (i + 1)) {
                 action = QString(argv[i + 1]).trimmed();
             }
+        } else if (arg == QStringLiteral("--version")) {
+            fprintf(stdout, "QOwnNotes %s\n", VERSION);
+            exit(0);
         }
     }
 
