@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2022 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@ namespace Ui {
 class MainWindow;
 }
 
+class HtmlPreviewWidget;
 class QMimeData;
 class QActionGroup;
 class QListWidgetItem;
@@ -86,6 +87,7 @@ class MainWindow : public QMainWindow {
    Q_SIGNALS:
     void currentNoteChanged(Note &note);
     void log(LogWidget::LogType logType, QString text);
+    void settingsChanged();
 
    public:
     enum CreateNewNoteOption {
@@ -116,7 +118,16 @@ class MainWindow : public QMainWindow {
 
     void setCurrentNoteText(QString text);
 
-    Note getCurrentNote();
+    void setCurrentNote(Note note, bool updateNoteText = true,
+                        bool updateSelectedNote = true,
+                        bool addPreviousNoteToHistory = true);
+
+    void createNewNote(QString noteName = QString(),
+                       bool withNameAppend = true);
+
+    void doSearchInNote(QString searchText);
+
+    const Note &getCurrentNote();
 
     void createNewNote(
         QString name, QString text,
@@ -177,8 +188,6 @@ class MainWindow : public QMainWindow {
 
     bool jumpToNoteSubFolder(int noteSubFolderId);
 
-    QString noteTextEditCurrentWord(bool withPreviousCharacters = false);
-
     Q_INVOKABLE bool createNewNoteSubFolder(QString folderName = QString());
 
     QString getLogText();
@@ -201,6 +210,14 @@ class MainWindow : public QMainWindow {
 
     Q_INVOKABLE bool insertDataUrlAsFileIntoCurrentNote(const QString &dataUrl);
 
+    class NoteSubFolderTree *noteSubFolderTree();
+
+    void openTodoDialog(const QString &taskUid = QString());
+
+    class QOwnNotesMarkdownTextEdit *noteTextEdit();
+
+    void refreshNotePreview();
+
    protected:
     void changeEvent(QEvent *event) override;
 
@@ -208,8 +225,6 @@ class MainWindow : public QMainWindow {
 
     bool eventFilter(QObject *obj, QEvent *event) override;
 
-    void resizeEvent(QResizeEvent *event) override;
-
    public slots:
     void setCurrentNoteFromNoteId(const int noteId);
 
@@ -254,7 +269,7 @@ class MainWindow : public QMainWindow {
 
     void on_action_New_note_triggered();
 
-    void on_noteTextView_anchorClicked(const QUrl &arg1);
+    void onNotePreviewAnchorClicked(const QUrl &arg1);
 
     void on_actionCheck_for_updates_triggered();
 
@@ -276,8 +291,6 @@ class MainWindow : public QMainWindow {
 
     void jumpToWelcomeNote();
 
-    void on_noteTextEdit_customContextMenuRequested(const QPoint pos);
-
     void pasteMediaIntoNote();
 
     void on_actionInsert_text_link_triggered();
@@ -437,8 +450,6 @@ class MainWindow : public QMainWindow {
 
     void reloadTodoLists();
 
-    void openTodoDialog(const QString &taskUid = QString());
-
     void showWindow();
 
     void on_actionOpen_IRC_Channel_triggered();
@@ -458,27 +469,16 @@ class MainWindow : public QMainWindow {
 
     void on_noteTreeWidget_itemChanged(QTreeWidgetItem *item, int column);
 
-    void on_noteSubFolderTreeWidget_currentItemChanged(
-        QTreeWidgetItem *current, QTreeWidgetItem *previous);
+    void onCurrentSubFolderChanged();
 
-    void on_noteSubFolderTreeWidget_itemSelectionChanged();
+    void onMultipleSubfoldersSelected();
 
     void clearTagFilteringColumn();
 
     void on_noteSubFolderLineEdit_textChanged(const QString &arg1);
 
-    void on_noteSubFolderTreeWidget_itemExpanded(QTreeWidgetItem *item);
-
-    void on_noteSubFolderTreeWidget_itemCollapsed(QTreeWidgetItem *item);
-
-    void on_noteSubFolderTreeWidget_customContextMenuRequested(
-        const QPoint pos);
-
     void on_noteSubFolderLineEdit_returnPressed();
 
-    void on_noteSubFolderTreeWidget_itemChanged(QTreeWidgetItem *item,
-                                                int column);
-
     void on_actionShare_note_triggered();
 
     void on_actionToggle_text_case_triggered();
@@ -577,14 +577,8 @@ class MainWindow : public QMainWindow {
 
     void on_actionCheck_for_script_updates_triggered();
 
-    void noteTextEditResize(QResizeEvent *event);
-
-    void encryptedNoteTextEditResize(QResizeEvent *event);
-
     void on_actionShow_local_trash_triggered();
 
-    void on_encryptedNoteTextEdit_customContextMenuRequested(const QPoint pos);
-
     void on_actionJump_to_note_text_edit_triggered();
 
     void on_tagTreeWidget_itemDoubleClicked(QTreeWidgetItem *item, int column);
@@ -677,6 +671,34 @@ class MainWindow : public QMainWindow {
 
     void on_actionImport_notes_from_Joplin_triggered();
 
+public:
+    /** Settings access **/
+    static bool isInDistractionFreeMode();
+    void setShowNotesFromAllNoteSubFolders(bool show);
+    bool showNotesFromAllNoteSubFolders() const;
+
+    /** Actions **/
+public:
+    QAction *newNoteAction();
+    QAction *reloadNoteFolderAction();
+    QAction *insertTextLinkAction();
+    QAction *searchTextOnWebAction();
+    QAction *pasteImageAction();
+    QAction *autocompleteAction();
+    QAction *splitNoteAtPosAction();
+    QList<QAction*> customTextEditActions();
+
+public:
+    /** export / print **/
+    void printTextDocument(QTextDocument *textDocument);
+    void exportNoteAsPDF(QTextDocument *doc);
+
+    int getMaxImageWidth() const;
+
+public:
+    void clearNoteDirectoryWatcher();
+    void updateNoteDirectoryWatcher();
+
 private:
     Ui::MainWindow *ui;
     QString notesPath;
@@ -757,7 +779,6 @@ private:
     IssueAssistantDialog *_issueAssistantDialog;
     StoredImagesDialog *_storedImagesDialog;
     StoredAttachmentsDialog *_storedAttachmentsDialog;
-    SettingsDialog *_settingsDialog;
     bool _noteExternallyRemovedCheckEnabled;
     QList<QAction *> _noteTextEditContextMenuActions;
     QList<QAction *> _noteListContextMenuActions;
@@ -770,21 +791,20 @@ private:
     QActionGroup *_languageGroup;
     QActionGroup *_spellBackendGroup;
     bool _brokenTagNoteLinksRemoved = false;
-    const QIcon _tagIcon = QIcon::fromTheme(
-        QStringLiteral("tag"),
-        QIcon(QStringLiteral(":/icons/breeze-qownnotes/16x16/tag.svg")));
-    const QIcon _folderIcon = QIcon::fromTheme(
-        QStringLiteral("folder"),
-        QIcon(QStringLiteral(":icons/breeze-qownnotes/16x16/folder.svg")));
-    const QIcon _noteIcon = QIcon::fromTheme(
-        QStringLiteral("text-x-generic"),
-        QIcon(":icons/breeze-qownnotes/16x16/text-x-generic.svg"));
+
+#ifdef USE_QLITEHTML
+    HtmlPreviewWidget *_notePreviewWidget = nullptr;
+#endif
+
     QList<QHotkey *> _globalShortcuts;
     int _lastNoteId = 0;
     bool _scriptUpdateFound = false;
     bool _isMaximizedBeforeFullScreen = false;
     bool _isMinimizedBeforeFullScreen = false;
-    CommandBar* _commandBar;
+
+    void initTreeWidgets();
+
+    void initNotePreviewAndTextEdits();
 
     void createSystemTrayIcon();
 
@@ -796,10 +816,6 @@ private:
 
     QString selectOwnCloudNotesFolder();
 
-    void setCurrentNote(Note note, bool updateNoteText = true,
-                        bool updateSelectedNote = true,
-                        bool addPreviousNoteToHistory = true);
-
     void removeCurrentNote();
 
     void searchInNoteTextEdit(QString str);
@@ -841,16 +857,6 @@ private:
 
     bool preparePrintNotePrinter(QPrinter *printer);
 
-    void printNote(QPlainTextEdit *textEdit);
-
-    void exportNoteAsPDF(QTextEdit *textEdit);
-
-    void exportNoteAsPDF(QTextDocument *doc);
-
-    void printNote(QTextEdit *textEdit);
-
-    void printTextDocument(QTextDocument *textDocument);
-
     void updateNoteEncryptionUI();
 
     void askForEncryptedNotePasswordIfNeeded(
@@ -876,14 +882,10 @@ private:
 
     bool insertMedia(QFile *file, QString title = QString());
 
-    int currentNoteLineNumber();
-
     static bool isValidMediaFile(QFile *file);
 
     static bool isValidNoteFile(QFile *file);
 
-    static bool isInDistractionFreeMode();
-
     void removeSelectedTags();
 
     void setupTags();
@@ -892,7 +894,7 @@ private:
 
     void highlightCurrentNoteTagsInTagTree();
 
-    void filterNotesBySearchLineEditText();
+    void filterNotesBySearchLineEditText(bool searchInNote = true);
 
     void filterNotes(bool searchForText = true);
 
@@ -926,8 +928,6 @@ private:
 
     void initScriptingEngine();
 
-    int getMaxImageWidth();
-
     void updateWindowTitle();
 
     void initSavedSearchesCompleter();
@@ -938,22 +938,13 @@ private:
 
     QTreeWidgetItem *firstVisibleNoteTreeWidgetItem();
 
-    QTreeWidgetItem *addNoteSubFolderToTreeWidget(
-        QTreeWidgetItem *parentItem, const NoteSubFolder &noteSubFolder);
-
-    void buildNoteSubFolderTreeForParentItem(QTreeWidgetItem *parent = nullptr);
-
     void setupNoteSubFolders();
 
     void filterNotesByNoteSubFolders();
 
-    void updateNoteDirectoryWatcher();
-
     bool addNoteToNoteTreeWidget(const Note &note,
                                  QTreeWidgetItem *parent = nullptr);
 
-    void removeSelectedNoteSubFolders(QTreeWidget *treeWidget);
-
     QTreeWidgetItem *findNoteInNoteTreeWidget(const Note &note);
 
     void jumpToNoteOrCreateNew(bool disableLoadNoteDirectoryList = false);
@@ -973,9 +964,6 @@ private:
 
     void copySelectedNotesToNoteSubFolder(const NoteSubFolder &noteSubFolder);
 
-    void createNewNote(QString noteName = QString(),
-                       bool withNameAppend = true);
-
     void initTagButtonScrollArea();
 
     static QIcon getSystemTrayIcon();
@@ -986,10 +974,6 @@ private:
 
     static void updateTreeWidgetItemHeight(QTreeWidget *treeWidget, int height);
 
-    bool solveEquationInNoteTextEdit(double &returnValue);
-
-    bool noteTextEditAutoComplete(QStringList &resultList);
-
     void initDockWidgets();
 
     void updateWorkspaceLists(bool rebuild = true);
@@ -1014,11 +998,6 @@ private:
 
     void assignColorToTagItem(QTreeWidgetItem *item);
 
-    static void handleTreeWidgetItemTagColor(QTreeWidgetItem *item,
-                                             const Tag &tag);
-    static void handleTreeWidgetItemTagColor(QTreeWidgetItem *item,
-                                             int tag);
-
     void disableColorOfTagItem(QTreeWidgetItem *item);
 
     void assignColorToSelectedTagItems();
@@ -1037,13 +1016,11 @@ private:
 
     static void startAppVersionTest();
 
-    bool showNotesFromAllNoteSubFolders();
-
     void selectAllNotesInNoteSubFolderTreeWidget() const;
 
     bool insertAttachment(QFile *file, const QString &title = QString());
 
-    static Qt::SortOrder toQtOrder(int order);
+    bool insertTextAsAttachment(const QString &text, const QString &title = QString());
 
     void updatePanelsSortOrder();
 
@@ -1072,11 +1049,6 @@ private:
 
     void applyFormatter(const QString &formatter);
 
-    bool isNoteTextSelected();
-
-    void noteTextEditCustomContextMenuRequested(
-        QOwnNotesMarkdownTextEdit *noteTextEdit, const QPoint pos);
-
     void updateNoteTextEditReadOnly();
 
     int getSelectedNotesCount() const;
@@ -1089,9 +1061,6 @@ private:
     void openNotesContextMenu(const QPoint globalPos,
                               bool multiNoteMenuEntriesOnly = false);
 
-    void openNoteSubFolderContextMenu(const QPoint globalPos,
-                                      QTreeWidget *treeWidget);
-
     void updateCurrentNoteTextHash();
 
     void centerAndResize();
@@ -1100,8 +1069,6 @@ private:
 
     void removeConflictedNotesDatabaseCopies();
 
-    void doSearchInNote(QString searchText);
-
     void insertNoteText(const QString &text);
 
     void handleNoteTextChanged();
@@ -1115,14 +1082,12 @@ private:
     void noteTextEditTextWasUpdated();
     void removeNoteFromNoteTreeWidget(Note &note) const;
     void initGlobalKeyboardShortcuts();
-    void clearNoteDirectoryWatcher();
     void resizeTagTreeWidgetColumnToContents() const;
-    void resizeNoteSubFolderTreeWidgetColumnToContents() const;
     void updateCurrentTabData(const Note &note) const;
     bool jumpToTab(const Note &note) const;
     void closeOrphanedTabs() const;
     void removeNoteTab(int index) const;
     void automaticScriptUpdateCheck();
-
     void updateJumpToActionsAvailability();
+    int getNoteTabIndex(int noteId) const;
 };
