@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2022 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -362,7 +362,7 @@ QString Utils::Misc::toStartCase(const QString &text) {
  *
  * @param executablePath the path of the executable
  * @param parameters a list of parameter strings
- * @param workingDirectory the directory to run the executable from
+ * @param workingDirectory the directory to run the executable from (optional)
  * @return true on success, false otherwise
  */
 bool Utils::Misc::startDetachedProcess(const QString &executablePath,
@@ -420,14 +420,20 @@ bool Utils::Misc::openFilesWithApplication(const QString &executablePath,
  *
  * @param executablePath the path of the executable
  * @param parameters a list of parameter strings
- * @param data the data that will be written to the process
+ * @param data the data that will be written to the process (optional)
+ * @param workingDirectory the working directory to execute the process in (optional)
  * @return the text that was returned by the process
  */
 QByteArray Utils::Misc::startSynchronousProcess(const QString &executablePath,
                                                 const QStringList &parameters,
-                                                const QByteArray &data) {
+                                                const QByteArray &data,
+                                                const QString &workingDirectory) {
     QProcess process;
 
+    if (!workingDirectory.isEmpty()) {
+        process.setWorkingDirectory(workingDirectory);
+    }
+
     // start executablePath synchronous with parameters
 #ifdef Q_OS_MAC
     process.start("open", QStringList()
@@ -559,7 +565,16 @@ QString Utils::Misc::portableDataPath() {
     QString path = QString();
 
     if (qApp != Q_NULLPTR) {
-        path = QCoreApplication::applicationDirPath();
+        // for AppImages we best take out the path directly from the first
+        // argument of the executable arguments, because the applicationDirPath
+        // will be some temporary path
+        if (Utils::Misc::isAppImage()) {
+            const QFileInfo fileInfo(qApp->property(
+                             "arguments").toStringList().at(0));
+            path = fileInfo.absolutePath();
+        } else {
+            path = QCoreApplication::applicationDirPath();
+        }
     }
 
     // use a fallback if the QApplication object wasn't instantiated yet
@@ -587,6 +602,15 @@ bool Utils::Misc::isInPortableMode() {
     return qApp != nullptr ? qApp->property("portable").toBool() : false;
 }
 
+/**
+ * Returns true if the app is an AppImage
+ *
+ * @return
+ */
+bool Utils::Misc::isAppImage() {
+    return qApp->property("release").toString().contains(QStringLiteral("AppImage"));
+}
+
 /**
  * Prepends the portable data path if we are in portable mode
  *
@@ -1808,6 +1832,12 @@ QString Utils::Misc::generateDebugInformation(bool withGitHubLineBreaks) {
                                                       ? QStringLiteral("yes")
                                                       : QStringLiteral("no"),
                                                   withGitHubLineBreaks);
+            output += prepareDebugInformationLine(QStringLiteral("allowDifferentNoteFileName"),
+                noteFolder.settingsValue(QStringLiteral("allowDifferentNoteFileName"))
+                                                  .toBool()
+                                                      ? QStringLiteral("yes")
+                                                      : QStringLiteral("no"),
+                                                  withGitHubLineBreaks);
             output += prepareDebugInformationLine(
                 QStringLiteral("activeNoteSubFolder name"),
                 noteFolder.getActiveNoteSubFolder().getName(),
@@ -1841,6 +1871,9 @@ QString Utils::Misc::generateDebugInformation(bool withGitHubLineBreaks) {
         output += prepareDebugInformationLine(QStringLiteral("username"),
                                               cloudConnection.getUsername(),
                                               withGitHubLineBreaks);
+        output += prepareDebugInformationLine(QStringLiteral("accountId"),
+                                              cloudConnection.getAccountId(),
+                                              withGitHubLineBreaks);
     }
 
     // add script information
