@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2022 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -81,6 +81,7 @@ char dirSeparator();
 void waitMsecs(int msecs);
 QString portableDataPath();
 bool isInPortableMode();
+bool isAppImage();
 QString prependPortableDataPathIfNeeded(QString path,
                                         bool ifNotEmptyOnly = false);
 QString makePathRelativeToPortableDataPathIfNeeded(QString path);
@@ -88,7 +89,8 @@ QString htmlToMarkdown(QString text);
 QString parseTaskList(const QString &html, bool clickable);
 QByteArray startSynchronousProcess(const QString &executablePath,
                                    const QStringList &parameters,
-                                   const QByteArray &data = QByteArray());
+                                   const QByteArray &data = QByteArray(),
+                                   const QString &workingDirectory = "");
 bool startSynchronousResultProcess(TerminalCmd &cmd);
 QList<QObject *> getParents(QObject *object);
 QString appDataPath();
