@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2022 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -363,7 +363,7 @@ void NotePreviewWidget::exportAsHTMLFile() {
     dialog.setFileMode(QFileDialog::AnyFile);
     dialog.setAcceptMode(QFileDialog::AcceptSave);
     dialog.setNameFilter(tr("HTML files") + " (*.html)");
-    dialog.setWindowTitle(tr("Export preview as raw HTML file"));
+    dialog.setWindowTitle(tr("Export preview as raw HTML file", "\"Raw\" means that actually the html that was fed to the preview will be stored (the QTextBrowser modifies the html that it is showing)"));
     dialog.selectFile(QStringLiteral("preview.html"));
     int ret = dialog.exec();
 
