@@ -23,7 +23,7 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     explicit QOwnNotesMarkdownTextEdit(QWidget *parent = nullptr);
 
     void setStyles();
-    void openUrl(QString urlString);
+    void openUrl(const QString &urlString) override;
     //    void setViewportMargins(int left, int top, int right, int bottom);
     void setPaperMargins(int width = -1);
     void setMainWindow(MainWindow *mainWindow);
@@ -36,6 +36,51 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     void disableSpellChecking();
     bool usesMonospacedFont();
 
+    /**
+    * Toggles the case of the word under the Cursor or the selected text
+    */
+    void toggleCase();
+
+    /**
+     * Inserts an empty code block
+     */
+    void insertCodeBlock();
+
+    /**
+     * Handles auto completion
+     */
+    void onAutoCompleteRequested();
+
+    /**
+     * Tries to find an equation in the current line and solves it
+     * @return true on success
+     */
+    bool solveEquation(double &returnValue);
+
+    /**
+     * Inserts a block quote character or formats the selected text as block quote
+     */
+    void insertBlockQuote();
+
+    /**
+     * Returns the text from the current cursor to the start of the word in the
+     * note text edit
+     *
+     * @param withPreviousCharacters also get more characters at the beginning
+     *                               to get characters like "@" that are not
+     *                               word-characters
+     * @return
+     */
+    QString currentWord(bool withPreviousCharacters = false) const;
+
+    /**
+     * Tries to find words that start with the current word in the note text edit
+     *
+     * @param resultList
+     * @return
+     */
+    bool autoComplete(QStringList &resultList) const;
+
    protected:
     // we must not override _highlighter or Windows will create a
     // QOwnNotesMarkdownHighlighter and MarkdownHighlighter instance
@@ -49,14 +94,17 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     void highlightCurrentLine();
 
    private:
-    MainWindow *mainWindow;
+    MainWindow *mainWindow = nullptr;
     bool _isSpellCheckingDisabled = false;
 
+    /// @param in is true if zoom-in, false otherwise
+    void onZoom(bool in);
+
     void setFormatStyle(MarkdownHighlighter::HighlighterState index);
 
-    bool onContextMenuEvent(QContextMenuEvent *event);
+    void onContextMenu(QPoint pos);
 
     void overrideFontSizeStyle(int fontSize);
-   Q_SIGNALS:
-    void resize(QResizeEvent *event);
+
+    QMenu *spellCheckContextMenu(QPoint pos);
 };
